==> cms-db_v0.9.tar.gz: admin/renamefile.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

include('checkuser.inc.php');
checkuser('includes');
include('locale.inc.php');
$locale = new LocalizingClass('files');
?>
<?php
if (isset($_POST['button']) && strpos($_POST['file'], '..') === false) {
	$file = $_POST['file'];
	$name = $_POST['new'];
	$name = str_replace(" " ,"_", $name);
	$name = str_replace("&" ,"AND", $name);
	if (!preg_match('/[^a-z0-9._-]/i', $name)) {
		$oldpath = '../data/files'.$file;
		$newpath = dirname($oldpath).'/'.$name;
		if (!file_exists($newpath)) {
			if (!rename($oldpath, $newpath)) {
				include('error.inc.php');
				throw_error(locale('desc_rename-error',true), 'renamefile.php?file='.$file.'&'.SID.csrf_protection_get());
			}
			header('Location: files.php?path='.dirname($_POST['file']).'&'.SID.csrf_protection_get());
		} else {
			include('error.inc.php');
			throw_error(locale('desc_error-filename',true), 'renamefile.php?file='.$file.'&'.SID.csrf_protection_get());
		}
	} else {
		include('error.inc.php');
		throw_error(locale('desc_rename-error-specialchars',true), 'renamefile.php?file='.$file.'&'.SID.csrf_protection_get());
	}
} else {
?>

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php locale('title_rename') ?></title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rel="stylesheet" type="text/css" href="style.css">
</head>
<body>

<h1><?php locale('title_rename') ?></h1>
<p>
	<form action="renamefile.php?<?php echo SID; csrf_protection_get_html() ?>" method="POST">
		<input type="hidden" name="file" value="<?php echo $_GET['file'] ?>" />
		<?php printf(locale('desc_rename',true), $_GET['file']) ?>
		<input type="text" name="new" value="" /><br />
		<input type="submit" name="button" value="<?php locale('button_ok') ?>">
		<a href="files.php?path=<?php echo dirname($_GET['file']) ?>&amp;<?php echo SID; csrf_protection_get_html() ?>" class="nonewtab"><?php locale('button_cancel') ?></a>
	</form>
</p>

</body>
</html>

<?php
}
?>

==> cms-db_v0.9.3.tar.gz: admin/renamefile.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

require_once('path.inc.php');
require_once(CDB_PATH_ADMIN.'/checkphp.inc.php');
require_once(CDB_PATH_ADMIN.'/checkuser.inc.php');
checkuser('includes');
require_once(CDB_PATH_ADMIN.'/locale.inc.php');
$locale = new LocalizingClass('files');
?>
<?php
if (isset($_POST['button']) && strpos($_POST['file'], '..') === false) {
	$file = $_POST['file'];
	$name = $_POST['new'];
	$name = str_replace(' ', '_', $name);
	$name = str_replace('&', 'AND', $name);
	if (!preg_match('/[^a-z0-9._-]/i', $name)) {
		$oldpath = '../data/files'.$file;
		$newpath = dirname($oldpath).'/'.$name;
		if (!file_exists($newpath)) {
			if (!rename($oldpath, $newpath)) {
				include('error.inc.php');
				throw_error(locale('desc_rename-error',true), 'renamefile.php?file='.$file.'&'.SID.csrf_protection_get());
			}
			header('Location: files.php?path='.dirname($_POST['file']).'&'.SID.csrf_protection_get());
		} else {
			include('error.inc.php');
			throw_error(locale('desc_error-filename',true), 'renamefile.php?file='.$file.'&'.SID.csrf_protection_get());
		}
	} else {
		include('error.inc.php');
		throw_error(locale('desc_rename-error-specialchars',true), 'renamefile.php?file='.$file.'&'.SID.csrf_protection_get());
	}
} else {
?>

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php locale('title_rename') ?></title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rel="stylesheet" type="text/css" href="style.css">
</head>
<body>

<h1><?php locale('title_rename') ?></h1>

<form action="renamefile.php?<?php echo SID; csrf_protection_get_html() ?>" method="POST">
	<input type="hidden" name="file" value="<?php echo $_GET['file'] ?>" />
	<fieldset>
		<p>
			<?php printf(locale('desc_rename',true), $_GET['file']) ?>
			<input type="text" name="new" value="" />
		</p>
	</fieldset>
	<p>
		<input type="submit" name="button" value="<?php locale('button_ok') ?>">
		<a href="files.php?path=<?php echo dirname($_GET['file']) ?>&amp;<?php echo SID; csrf_protection_get_html() ?>" class="nonewtab"><?php locale('button_cancel') ?></a>
	</p>
</form>

</body>
</html>

<?php
}
?>
